pub struct NatId(pub u16);Expand description
NAT identifier calculated from checksum difference.
When a NAT rewrites a packet (changing IP/port), the UDP checksum changes. The NAT ID is the difference between the received and sent checksums. If the NAT ID changes between hops, NAT was detected at that hop.
Tuple Fields
0: u16Implementations
Sourceimpl NatId
impl NatId
Sourcepub fn from_checksums(sent_checksum: u16, received_checksum: u16) -> Self
pub fn from_checksums(sent_checksum: u16, received_checksum: u16) -> Self
Calculate NAT ID from sent and received UDP checksums.
NAT ID = received_checksum - sent_checksum
If NAT rewrites the packet, the checksum changes and NAT ID will be non-zero. If NAT ID differs between hops, a NAT device exists at that point.